@@ -6,7 +6,7 @@ test_that("Vocabulary with UTF-8 strings", {
                              "标准间", "从", "新", "改善")))
   it = itoken(all_text,ids = 1, progressbar = FALSE)
   vocab = create_vocabulary(it)
-  expect_true(all(Encoding(vocab$vocab$terms) == 'UTF-8'))
-  expect_equal(setdiff(unique(all_text[[1]]), vocab$vocab$terms), character(0))
-  expect_equal(setdiff(vocab$vocab$terms, unique(all_text[[1]])), character(0))
+  expect_true(all(Encoding(vocab$term) == 'UTF-8'))
+  expect_equal(setdiff(unique(all_text[[1]]), vocab$term), character(0))
+  expect_equal(setdiff(vocab$term, unique(all_text[[1]])), character(0))
 })
